@@ -361,7 +361,7 @@ class Fs_sip_status extends Safe_CI_Controller
                                 $chan_info->name,
                                 //$chan_info->state,
                                 $chan_info->cid_name,
-                                $chan_info->read_codec,
+                                $chan_info->callee_name,
                                 $chan_info->write_codec,
                                 //$chan_info->callstate,
                                 $state,
