@@ -394,8 +394,14 @@ class Safe_module_class extends Safe_object_class
      */
     public function data_key_exists($data_name, $key)
     {
-        $data_files = $this->get_data_files($data_name);
-        return (isset($data_files[$key]));
+        $data_cfg = $this->get_data_settings();
+        if (isset($data_cfg[$data_name]) && true == $data_cfg[$data_name]['filesystem'] && isset($data_cfg[$data_name]['pattern'])) {
+            $tmp_file_name = basename($key);
+            $tmp_ext = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_EXTENSION);
+            $tmp_file_path = pathinfo($data_cfg[$data_name]['pattern'] , PATHINFO_DIRNAME );
+            return  $this->node()->os()->check_file_exists($tmp_file_path .'/' . $tmp_file_name.'.'.$tmp_ext);
+        }
+        throw new Exception('Module ' . $this->description() . ' data_key_exists error for ' . $data_name);
     }
     /**
      * @brief Delete all data
